
******************
amethyst.core.util
******************

.. currentmodule:: amethyst.core.util
.. autosummary::

    cached_property
    coalesce
    dict_of
    get_class
    identity
    list_of
    set_of
    smartmatch
    tupley

.. automodule:: amethyst.core.util
   :members:
